import * as React from 'react';
import {Box, Grid, Table, TableBody, TableCell, TableRow, Toolbar} from "@material-ui/core";
import Typography from "@material-ui/core/Typography";
import {t} from "@lingui/macro";
import {AppStatusIcon} from "../../pages/apps/AppStatusIcon";
import {RestartButton} from "../../pages/apps/RestartButton";
import {RxModuleComponentModel} from "../../stores/RxModuleComponentStore";
import {StopButton} from "../../pages/apps/StopButton";
import {UpdateAvailableTableRow} from "./app_info/UpdateAvailableTableRow";
import {IconTableRow} from "./app_info/IconTableRow";
import {PaddedPaper} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {DateTableCell} from "./app_info/DateTableCell";
import {PingResult} from './app_info/PingResult';

type Props = {
    model: RxModuleComponentModel
}

export const AppInfo: React.FunctionComponent<Props> = observer(({model}) => {
    return (
        <Grid item md={6} xs={12}>
            <PaddedPaper>
                <Toolbar><Typography variant={'h4'}>{t`App Info`}</Typography></Toolbar>
                <Table>
                    <TableBody>
                        <TableRow>
                            <TableCell>{model.attribute('module_name')!.label}</TableCell>
                            <TableCell>{model.module_name}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>{model.attribute('version')!.label}</TableCell>
                            <TableCell>{model.version}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>{model.attribute('description')!.label}</TableCell>
                            <TableCell>{model.description}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>{model.attribute('reachable')!.label}</TableCell>
                            <TableCell>
                                <Box display={"flex"} alignItems={"center"}>
                                    <AppStatusIcon reachable={model.reachable}/>
                                    <RestartButton model={model as RxModuleComponentModel}/>
                                    <StopButton model={model as RxModuleComponentModel}/>
                                </Box>
                            </TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>{model.attribute('last_ping_at')!.label}</TableCell>
                            <DateTableCell date={model.last_ping_at}/>
                        </TableRow>
                        <TableRow>
                            <TableCell>{model.attribute('last_successful_ping_at')!.label}</TableCell>
                            <DateTableCell date={model.last_successful_ping_at}/>
                        </TableRow>
                        <TableRow>
                            <TableCell>{model.attribute('last_ping_result')!.label}</TableCell>
                            <TableCell>
                                <PingResult result={model.last_ping_result}/>
                            </TableCell>
                        </TableRow>
                        <UpdateAvailableTableRow model={model}/>
                        <IconTableRow model={model as RxModuleComponentModel}/>
                    </TableBody>
                </Table>
            </PaddedPaper>
        </Grid>
    )
});