import {ButtonProps} from "@material-ui/core";
import * as React from "react";
import {observer} from "mobx-react-lite";
import {Check, Clear} from "@material-ui/icons";
import {Permission} from "../../stores/RoleStore";
import {makeStyles} from "@material-ui/core/styles";
import {GrantedButton} from "./GrantedButton";
import {DeniedButton} from "./DeniedButton";
import classNames from "classnames";

type PermissionButtonProps = {
    componentAction: Permission
} & ButtonProps;

const useStyles = makeStyles({
    fixedWidth: {
        width: 125,
        // whiteSpace: "nowrap",
        // overflow: "hidden",
        paddingLeft: 2
    },
});

export const ComponentPermissionButton: React.FunctionComponent<PermissionButtonProps> = observer((props) => {
    const {componentAction, className, ...otherProps} = props;
    const model = componentAction.rolePermission.viewModel;
    const classes = useStyles();

    const handleClick = React.useCallback(() => {
        model.permitted = !model.permitted
    }, [model]);

    let Component;
    if (model.permitted) {
        Component = GrantedButton;
    } else {
        Component = DeniedButton;
    }
    return (
        <Component
            {...otherProps}
            className={classNames(className, classes.fixedWidth)}
            onClick={handleClick}
            startIcon={model.permitted ? <Check/> : <Clear/>}
        >
            {componentAction.componentPermission.action_display_name}
        </Component>
    );
});



