import * as React from 'react';
import {observer} from "mobx-react-lite";
import {FormProps, ModelCheckbox, ModelForm, ModelInput, ModelSelect, PaddedPaper} from "@rx-suite/ui";
import {t, Trans} from '@lingui/macro';
import {Container, Grid, Typography} from '@material-ui/core';
import {EmailSelect} from "../../components/emails/EmailSelect";
import {RxModuleComponentModel} from "../../stores/RxModuleComponentStore";
import {AppInfo} from "../../components/apps/AppInfo";
import {LogSettings} from '../../components/apps/LogSettings';

export const AppForm: React.FunctionComponent<FormProps> = observer(({model, readOnly}) => {
        return (
            <Container maxWidth={false}>
                <Grid container spacing={2}>
                    <Grid item md={model.isNew ? 12 : 6} xs={12}>
                        <PaddedPaper>
                            <ModelForm model={model} readOnly={readOnly} suppressWrapper>
                                <ModelSelect name={"type"} options={[
                                    {label: t`Rx-Module`, value: 'RxModuleComponent'},
                                    {label: t`Rx-Universe API`, value: 'RxUniverseApiComponent'},
                                    {label: t`MES API`, value: 'MesApiComponent'},
                                    {label: t`Router API`, value: 'RouterApiComponent'}
                                ]}/>
                                <ModelSelect name={"protocol"} options={[
                                    {label: t`HTTP`, value: 'http'},
                                    {label: t`HTTPS`, value: 'https'}
                                ]}/>
                                <ModelCheckbox name={"delegate_requests_through_hub"} />
                                <ModelInput name={"external_port"} />
                                <ModelInput name={"external_address"} />
                                <ModelInput name={"port"} />
                                <ModelInput name={"ip_address"} />
                                <EmailSelect model={model} readOnly={readOnly}/>
                            </ModelForm>
                        </PaddedPaper>
                    </Grid>

                    <AppInfo model={model as RxModuleComponentModel}/>

                    <Grid item xs={12}>
                        <PaddedPaper>
                            <Typography variant={"h3"}><Trans>Log Settings</Trans></Typography>
                            <LogSettings model={model}/>
                        </PaddedPaper>

                    </Grid>
                </Grid>
            </Container>

        )

    }
);
