# == Schema Information
#
# Table name: role_permissions
#
#  id                      :bigint           not null, primary key
#  permitted               :boolean
#  created_at              :datetime         not null
#  updated_at              :datetime         not null
#  component_permission_id :bigint           not null
#  role_id                 :bigint           not null
#
# Indexes
#
#  index_role_permissions_on_component_permission_id  (component_permission_id)
#  index_role_permissions_on_role_id                  (role_id)
#
# Foreign Keys
#
#  fk_rails_...  (component_permission_id => component_permissions.id) ON DELETE => cascade
#  fk_rails_...  (role_id => roles.id) ON DELETE => cascade
#
class RolePermission < ApplicationRecord
  belongs_to :role
  belongs_to :component_permission

  validates :permitted, inclusion: [true, false]
  validates :role, presence: true
  validates :component_permission, presence: true

  def self.display_name
    "Role Permissions"
  end

  def should_broadcast?
    false
  end

  def flat
    component_permission_json = component_permission.as_json(
      exclude: [:id, :component_permission_id, :role_id, :created_at, :updated_at],
      include: {
        component: {
          only: :module_id
        }
      }
    )
    component_permission_json["component"] = component_permission_json["component"]["module_id"]

    as_json.merge(component_permission_json)
  end
end
